==> eds_scikit-0.1.2-py3-none-any.whl: eds_scikit/io/files.py <==
import os
from typing import List, Tuple

import pandas as pd

from . import settings


class PandasData:  # pragma: no cover
    def __init__(
        self,
        folder: str,
    ):
        """Pandas interface to OMOP data stored as local parquet files/folders.


        Parameters
        ----------
        folder: str
            absolute path to a folder containing several parquet files with OMOP data

        Examples
        --------
        >>> data = PandasData(folder="/export/home/USER/my_data/")
        >>> person = data.person
        >>> person.shape
        (100, 10)

        """

        self.available_tables, self.tables_paths = self.list_available_tables(folder)
        if not self.available_tables:
            raise ValueError(f"Folder {folder} does not contain any parquet omop data.")

    @staticmethod
    def list_available_tables(folder: str) -> Tuple[List[str], List[str]]:
        available_tables = []
        tables_paths = {}
        known_omop_tables = settings.tables_to_load.keys()
        for filename in os.listdir(folder):
            table_name, extension = os.path.splitext(filename)
            if extension == ".parquet" and table_name in known_omop_tables:
                abspath = os.path.abspath(os.path.join(folder, filename))
                tables_paths[table_name] = abspath
                available_tables.append(table_name)

        return available_tables, tables_paths

    def _read_table(self, table_name: str) -> pd.DataFrame:
        path = self.tables_paths[table_name]
        return pd.read_parquet(path)

    def __getattr__(self, table_name: str) -> pd.DataFrame:
        if table_name in self.available_tables:
            return self._read_table(table_name)
        else:
            raise AttributeError(
                f"Table '{table_name}' does is not available in chosen folder."
            )

    def __dir__(self) -> List[str]:
        return list(super().__dir__()) + list(self.available_tables)

==> eds_scikit-0.1.5-py3-none-any.whl: eds_scikit/io/files.py <==
import os
from typing import List

import pandas as pd

from .base import BaseData


class PandasData(BaseData):  # pragma: no cover
    def __init__(
        self,
        folder: str,
    ):
        """Pandas interface to OMOP data stored as local parquet files/folders.


        Parameters
        ----------
        folder: str
            absolute path to a folder containing several parquet files with OMOP data

        Examples
        --------
        >>> data = PandasData(folder="/export/home/USER/my_data/")
        >>> person = data.person
        >>> person.shape
        (100, 10)

        """
        super().__init__()
        self.folder = folder
        self.available_tables = self.list_available_tables()
        self.tables_paths = self.get_table_path()
        if not self.available_tables:
            raise ValueError(f"Folder {folder} does not contain any parquet omop data.")

    def list_available_tables(self) -> List[str]:
        available_tables = []
        for filename in os.listdir(self.folder):
            table_name, extension = os.path.splitext(filename)
            if extension == ".parquet":
                available_tables.append(table_name)

        return available_tables

    def get_table_path(self) -> List[str]:
        tables_paths = {}
        for filename in os.listdir(self.folder):
            table_name, extension = os.path.splitext(filename)
            if extension == ".parquet":
                abspath = os.path.abspath(os.path.join(self.folder, filename))
                tables_paths[table_name] = abspath

        return tables_paths

    def _read_table(self, table_name: str) -> pd.DataFrame:
        path = self.tables_paths[table_name]
        return pd.read_parquet(path)

    def __getattr__(self, table_name: str) -> pd.DataFrame:
        if table_name in self.available_tables:
            return self._read_table(table_name)
        else:
            raise AttributeError(
                f"Table '{table_name}' does is not available in chosen folder."
            )
